Index: pkg/dartino_compiler/lib/src/verbs/x_servicec_verb.dart |
diff --git a/pkg/fletchc/lib/src/verbs/x_servicec_verb.dart b/pkg/dartino_compiler/lib/src/verbs/x_servicec_verb.dart |
similarity index 95% |
rename from pkg/fletchc/lib/src/verbs/x_servicec_verb.dart |
rename to pkg/dartino_compiler/lib/src/verbs/x_servicec_verb.dart |
index d2456a9f36180f51a5a801091ec86c86d63a983d..663a284f258df37413352111b5e39e971d2dac22 100644 |
--- a/pkg/fletchc/lib/src/verbs/x_servicec_verb.dart |
+++ b/pkg/dartino_compiler/lib/src/verbs/x_servicec_verb.dart |
@@ -2,7 +2,7 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-library fletchc.verbs.servicec_verb; |
+library dartino_compiler.verbs.servicec_verb; |
import 'dart:io' show |
File, |
@@ -28,7 +28,7 @@ import 'documentation.dart' show |
import "package:compiler/src/util/uri_extras.dart" show |
relativize; |
-import "package:fletchc/src/guess_configuration.dart" show |
+import "package:dartino_compiler/src/guess_configuration.dart" show |
executable; |
const Action servicecAction = const Action( |
@@ -73,7 +73,7 @@ Uri guessServicecDir(Uri base) { |
Uri servicecDirectory; |
if (_SERVICEC_DIR != null) { |
// Use Uri.base here because _SERVICEC_DIR is a constant relative to the |
// location of where fletch was called from, not relative to the C++ |
// client. |
servicecDirectory = base.resolve(_SERVICEC_DIR); |
} else { |
@@ -73,7 +73,7 @@ Uri guessServicecDir(Uri base) { |
if (_SERVICEC_DIR != null) { |
// Use Uri.base here because _SERVICEC_DIR is a constant relative to the |
- // location of where fletch was called from, not relative to the C++ |
+ // location of where dartino was called from, not relative to the C++ |
// client. |
servicecDirectory = base.resolve(_SERVICEC_DIR); |